@@ -16,11 +16,9 @@ def enhance(img):
     x = img.astype('float32')
     x = x.transpose(2,0,1)[None,:]
     x -= 0.5; x *= 2
-    start = time()
     feat = A.run(None, {'input':x})[0]
     feat_map = mapping.run(None, {'input':feat})[0]
     y = B.run(None, {'input':feat_map})[0]
-    print(time()-start)
     y += 1; y /= 2
     return y[0].transpose(1,2,0)
 
